package model;

import org.json.JSONArray;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

public class GameState
{
	long[] fish; //Array of three bitboards: one for every fish value
	boolean can_play_red, can_play_blue; //If the red(blue) player can play or if it has no moves left
	Player current_player;
	Map<Player, int[]> penguins; //For every player, the list of his penguins
	Map<Player, Integer> score; //Score of every player

	public GameState()
	{
		fish = new long[3];
		penguins = new HashMap<>();
		penguins.put(Player.Red, new int[4]);
		penguins.put(Player.Blue, new int[4]);
		score = new HashMap<>();
		score.put(Player.Red, 0);
		score.put(Player.Blue, 0);
	}

	public void update(String jsonString)
	{
		//System.out.println(jsonString);
		JSONObject json = new JSONObject(jsonString);
		can_play_red = json.getJSONObject("can_play").getBoolean("red");
		can_play_blue = json.getJSONObject("can_play").getBoolean("blue");
		current_player = Player.valueOf(json.getString("current_player"));
		fish[0] = json.getJSONObject("bitboards").getLong("onefish");
		fish[1] = json.getJSONObject("bitboards").getLong("twofish");
		fish[2] = json.getJSONObject("bitboards").getLong("threefish");
		score.put(Player.Red, json.getJSONObject("score").getInt("red"));
		score.put(Player.Blue, json.getJSONObject("score").getInt("blue"));
		JSONArray jsonPeng = json.getJSONObject("penguins").getJSONArray("red");
		for (int i = 0; i < jsonPeng.length(); i++)
			penguins.get(Player.Red)[i] = jsonPeng.getInt(i);
		jsonPeng = json.getJSONObject("penguins").getJSONArray("blue");
		for (int i = 0; i < jsonPeng.length(); i++)
			penguins.get(Player.Blue)[i] = jsonPeng.getInt(i);
	}

	;

	/**
	 * @param tileNb The number of the tile we want to know the value of
	 * @return The number of fish on the tile, or 0 if empty
	 */
	public int getNbFish(int tileNb)
	{
		if (((fish[0] >>> tileNb) & 1) == 1)
			return 1;
		else if (((fish[1] >>> tileNb) & 1) == 1)
			return 2;
		else if (((fish[2] >>> tileNb) & 1) == 1)
			return 3;
		return 0;
	}

	public int getPenguinPos(int i, Player player)
	{
		//TODO
		return 0;
	}

	public boolean getCan_play_red()
	{
		return can_play_red;
	}

	public boolean getCan_play_blue()
	{
		return can_play_blue;
	}

	public Player getCurrent_player()
	{
		return current_player;
	}

	public int getScore(Player player)
	{
		return score.get(player);
	}

}
